@@ -1,80 +1,116 @@
 #' Tools for creating new parameter objects
-#' 
-#' These functions are used to construct new parameter objects. 
-#' 
-#' @param type A single character value. For quantitative parameters, valid 
-#' choices are "double" and "integer" while for qualitative factors they are 
-#' "character" and "logical". 
-#' @param range A two-element list of vector with the lowest or largest possible
-#'  values, respectively. If these cannot be set when the parameter is defined, 
-#'  the `unknown()` function can be used. If a transformation is specified, 
+#'
+#' These functions are used to construct new parameter objects. Generally,
+#' these functions are called from higher level parameter generating functions
+#' like [mtry()].
+#'
+#' @param type A single character value. For quantitative parameters, valid
+#' choices are `"double"` and `"integer"` while for qualitative factors they are
+#' `"character"` and `"logical"`.
+#'
+#' @param range A two-element vector with the smallest or largest possible
+#'  values, respectively. If these cannot be set when the parameter is defined,
+#'  the `unknown()` function can be used. If a transformation is specified,
 #'  these values should be in the _transformed units_.
-#' @param inclusive A two-element logical vector for whether the the range 
-#'  values should be inclusive or exclusive. 
-#' @param default A single value the same class as `type` for the default 
-#' parameter value. `unknown()` can also be used here. 
+#'
+#' @param inclusive A two-element logical vector for whether the range
+#'  values should be inclusive or exclusive.
+#'
+#' @param default A single value the same class as `type` for the default
+#' parameter value. `unknown()` can also be used here.
+#'
 #' @param trans A `trans` object from the \pkg{scales} package, such as
-#'  [scales::log10_trans()] or [scales::reciprocal_trans()]. 
+#' [scales::log10_trans()] or [scales::reciprocal_trans()]. Create custom
+#' transforms with [scales::trans_new()].
+#'
 #' @param values A vector of possible values that is required when `type` is
-#' "character" or "logical" but optional otherwise.  
+#' `"character"` or `"logical"` but optional otherwise. For quantitative
+#' parameters, these override the `range` when generating sequences if set.
+#'
 #' @param label An optional named character string that can be used for
-#' printing and plotting. The named should reflect the object name (e.g. 
-#' "mtry", "neighbors", etc.)
-#' @param finalize A function that can be used to set the  data-specific 
-#'  values of a parameter (such as the range).
-#' @return An object of class "param" with the primary class being either 
-#' "quant_param" or "qual_param". The `range` element of the object is always 
-#' converted to a list with elements "lower" and "upper". '
+#' printing and plotting. The name should match the object name (e.g.
+#' `"mtry"`, `"neighbors"`, etc.)
+#'
+#' @param finalize A function that can be used to set the data-specific
+#' values of a parameter (such as the `range`).
+#'
+#' @return
+#'
+#' An object of class `"param"` with the primary class being either
+#' `"quant_param"` or `"qual_param"`. The `range` element of the object
+#' is always converted to a list with elements `"lower"` and `"upper"`.
+#'
 #' @examples
-#' num_subgroups <-
+#' # Create a function that generates a quantitative parameter
+#' # corresponding to the number of subgroups.
+#' num_subgroups <- function(range = c(1L, 20L), trans = NULL) {
 #'   new_quant_param(
 #'     type = "integer",
-#'     range = c(1L, 20L),
+#'     range = range,
 #'     inclusive = c(TRUE, TRUE),
-#'     trans = NULL,
+#'     trans = trans,
 #'     label = c(num_subgroups = "# Subgroups"),
 #'     finalize = NULL
 #'   )
+#' }
+#'
+#' num_subgroups()
+#'
+#' num_subgroups(range = c(3, 5))
+#'
+#' # Custom parameters instantly have access
+#' # to sequence generating functions
+#' value_seq(num_subgroups(), 5)
+#'
+#' @name new-param
+#'
+NULL
+
 #' @export
-#' @importFrom scales is.trans
+#' @rdname new-param
 new_quant_param <- function(
-  type = c("double", "integer"), range, inclusive, 
+  type = c("double", "integer"), range, inclusive,
   default = unknown(),
   trans = NULL, values = NULL, label = NULL, finalize = NULL) {
   type <- match.arg(type)
-  
+
+  if (!(type %in% c("double", "integer"))) {
+    stop("`type should be either 'double' or 'integer'.", call. = FALSE)
+  }
+
+
   range <- as.list(range)
-  
+
   if (length(inclusive) != 2)
     stop("`inclusive` must have upper and lower values.", all. = FALSE)
   if (any(is.na(inclusive)))
     stop("Boundary descriptors must be non-missing.", call. = FALSE)
   if (!is.logical(inclusive))
-    stop("`inclusive` should be logical", call. = FALSE)  
-  
+    stop("`inclusive` should be logical", call. = FALSE)
+
   if (!is.null(trans)) {
     if (!is.trans(trans))
       stop(
-        "`trans` must be a 'trans' class object (or NULL). See ", 
+        "`trans` must be a 'trans' class object (or NULL). See ",
         "`?scales::trans_new`.", call. = FALSE
       )
   }
-  
+
   check_label(label)
   check_finalize(finalize)
-  
+
   names(range) <- names(inclusive) <- c("lower", "upper")
-  res <- list(type = type, range = range, inclusive = inclusive, 
+  res <- list(type = type, range = range, inclusive = inclusive,
               trans = trans, default = default,
               label = label, finalize = finalize)
   class(res) <- c("quant_param", "param")
   range_validate(res, range)
-  
+
   if (!is.null(values)) {
     ok_vals <- value_validate(res, values)
     if(all(ok_vals))
       res$values <- values
-    else 
+    else
       stop("Some values are not valid: ",
            glue_collapse(
              values[!ok_vals],
@@ -83,17 +119,17 @@ new_quant_param <- function(
              width = min(options()$width - 30, 10)
            ))
   }
-  
+
   res
 }
 
 #' @export
-#' @rdname new_quant_param
+#' @rdname new-param
 new_qual_param <- function(type = c("character", "logical"), values,
-                           default = unknown(), label = NULL, 
+                           default = unknown(), label = NULL,
                            finalize = NULL) {
   type <- match.arg(type)
-  
+
   if (type == "logical") {
     if (!is.logical(values))
       stop("`values` must be logical", call. = FALSE)
@@ -104,14 +140,14 @@ new_qual_param <- function(type = c("character", "logical"), values,
   }
   if (is_unknown(default))
     default <- values[1]
-  
+
   check_label(label)
   check_finalize(finalize)
-  
+
   res <- list(type = type, default = default,
-              label = label, values = values, 
+              label = label, values = values,
               finalize = finalize)
-  class(res) <- c("qual_param", "param") 
+  class(res) <- c("qual_param", "param")
 
   res
 }
@@ -120,8 +156,6 @@ new_qual_param <- function(type = c("character", "logical"), values,
 ###################################################################
 
 #' @export
-#' @importFrom purrr map_chr
-#' @importFrom glue glue
 print.quant_param <- function(x, digits = 3, ...) {
   if (!is.null(x$label)) {
     cat(x$label, " (quantitative)\n")
@@ -132,15 +166,15 @@ print.quant_param <- function(x, digits = 3, ...) {
     cat("Range (transformed scale): ")
   } else
     cat("Range: ")
-  
+
   vals <- map_chr(x$range, format_range_val)
   bnds <- format_bounds(x$inclusive)
   cat(glue('{bnds[1]}{vals[1]}, {vals[2]}{bnds[2]}\n'))
+  cat("\n")
   invisible(x)
 }
 
 #' @export
-#' @importFrom glue glue_collapse
 print.qual_param <- function(x, ...) {
   if (!is.null(x$label)) {
     cat(x$label, " (qualitative)\n")
@@ -149,7 +183,7 @@ print.qual_param <- function(x, ...) {
   cat(length(x$values), "possible value include:\n")
   if (x$type == "character")
     lvls <- paste0("'", x$values, "'")
-  else 
+  else
     lvls <- x$values
   cat(
     glue_collapse(
