@@ -18,13 +18,12 @@ format_bounds <- function(bnds) {
 }
 
 # From parsnip:::check_installs
-#' @importFrom utils installed.packages
-check_installs <- function (x) {
+check_installs <- function(x) {
   lib_inst <- rownames(installed.packages())
   is_inst <- x %in% lib_inst
   if (any(!is_inst)) {
     stop(
-      "This engine requires some package installs: ",
+      "Package(s) not installed: ",
       paste0("'", x[!is_inst], "'", collapse = ", "),
       call. = FALSE
     )
@@ -35,13 +34,13 @@ check_installs <- function (x) {
 
 check_label <- function(txt) {
   if (is.null(txt))
-    stop("`label` should be a single named character string or NULL.", 
+    stop("`label` should be a single named character string or NULL.",
          call. = FALSE)
   if (!is.character(txt) || length(txt) > 1)
-    stop("`label` should be a single named character string or NULL.", 
+    stop("`label` should be a single named character string or NULL.",
          call. = FALSE)
   if(length(names(txt)) != 1)
-    stop("`label` should be a single named character string or NULL.", 
+    stop("`label` should be a single named character string or NULL.",
          call. = FALSE)
   invisible(txt)
 }
