@@ -9,18 +9,18 @@ test_that('regular grid', {
   )
   expect_error(
     grid_regular()
-  )  
+  )
   expect_error(
-    grid_regular(mixture, trees, levels = 1:4)
+    grid_regular(mixture(), trees(), levels = 1:4)
   )
   expect_equal(
-    nrow(grid_regular(mixture, trees, levels = 2)),
+    nrow(grid_regular(mixture(), trees(), levels = 2)),
     4
-  )  
+  )
   expect_equal(
-    nrow(grid_regular(mixture, trees, levels = 2:3)),
+    nrow(grid_regular(mixture(), trees(), levels = 2:3)),
     prod(2:3)
-  )    
+  )
 })
 
 test_that('random grid', {
@@ -29,10 +29,10 @@ test_that('random grid', {
   )
   expect_error(
     grid_random()
-  )  
+  )
   expect_equal(
-    nrow(grid_random(mixture, trees, size = 2)),
+    nrow(grid_random(mixture(), trees(), size = 2)),
     2
-  )  
+  )
 })
 
